@@ -2,26 +2,21 @@ package Test::Clustericious::Cluster;
 
 use strict;
 use warnings;
-use v5.10;
-
-BEGIN {
-  unless($INC{'File/HomeDir/Test.pm'})
-  {
-    eval q{ use File::HomeDir::Test };
-    die $@ if $@;
-  }
-}
-
+use 5.010001;
+use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
+use Test2::API qw( context );
 use File::HomeDir;
 use Mojo::URL;
-use Test::Mojo;
 use Mojo::Loader;
 use Mojo::UserAgent;
-use base qw( Test::Builder::Module );
-use Carp qw( croak );
+use Carp qw( croak carp );
+use File::Basename ();
+use File::Path ();
+use Test::Mojo;
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.14_01'; # VERSION
+our $VERSION = '0.36_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -36,6 +31,7 @@ sub new
   {
     # undocumented and deprecated
     # you can pass in just an instance of Test::Mojo
+    carp "passing a Test::Mojo object into Test::Clustericious::Cluster->new deprecated";
     $args = { t => $_[0] };
   }
   else
@@ -43,8 +39,6 @@ sub new
     $args = ref $_[0] ? { %{ $_[0] } } : {@_};
   }
 
-  my $t = $args->{t} // Test::Mojo->new;
-  
   my $sep = $^O eq 'MSWin32' ? ';' : ':';
   my $lite_path = [ split $sep, $ENV{PATH} ];
 
@@ -52,21 +46,41 @@ sub new
   unshift @$lite_path, ref($args->{lite_path}) ? @{ $args->{lite_path} } : ($args->{lite_path});
   
   bless { 
-    t           => $t, 
+    t           => $args->{t},
     urls        => [], 
     apps        => [], 
+    stopped     => [],
     index       => -1,
     url         => '', 
     servers     => [],
     app_servers => [],
     auth_url    => '',
-    extra_ua    => [$t->ua],
+    #extra_ua    => [$t->ua],
     lite_path   => $lite_path,
   }, $class;
 }
 
 
-sub t { shift->{t} }
+sub t {
+  my($self) = @_;
+  $self->{t} //= do {
+    my $t = $self->{t} = Test::Mojo->new;
+    $self->_update_default_server;
+    $t;
+  };
+}
+
+sub _update_default_server
+{
+  my($self) = @_;
+  $self->t->ua->server->app($self->apps->[-1])
+    if $self->{t} && @{ $self->apps } && !$self->{stopped}->[-1];
+}
+
+sub _extra_ua {
+  my($self) = @_;
+  $self->{extra_ua} //= [ $self->t->ua ];
+}
 
 
 sub urls { shift->{urls} }
@@ -84,31 +98,33 @@ sub url { shift->{url} }
 sub auth_url { shift->{auth_url} }
 
 
-our $inc_hook;
-
 BEGIN {
+  # TODO
+  # so we muck with this @INC in two places.  Here we do it so
+  # that you can use_ok files in your .t file.  Later we do 
+  # extract files in create_cluster_ok and add ~/lib to the @INC
+  # path so that we can load as regular files.  This is more
+  # reliable for anything that expects a real live file, and we'd
+  # like to do that for use_ok as well in the future.
+
   unshift @INC, sub {
     my($self, $file) = @_;
 
-    return $inc_hook->($self, $file) if $inc_hook;
-   
-    state $loader;
-    unless(defined $loader)
-    {
-      $loader = Mojo::Loader->new;
-      $loader->load('main');
-    }
-  
-    my $data = $loader->data('main', "lib/$file");
+    my $data = Mojo::Loader::data_section('main', "lib/$file");
     return unless defined $data;
+    
+    # This will make the file really there.
+    # Some stuff depends on that
+    __PACKAGE__->extract_data_section("lib/$file", 'main');
+
     open my $fh, '<', \$data;
   
     # fake out %INC because Mojo::Home freeks the heck
     # out when it sees a CODEREF on some platforms
     # in %INC
     my $home = File::HomeDir->my_home;
-    mkdir "$home/mojohome" unless -d "$home/mojohome";
-    $INC{$file} = "$home/mojohome/$file";
+    mkdir "$home/lib" unless -d "$home/lib";
+    $INC{$file} = "$home/lib/$file";
   
     return $fh;
   };
@@ -140,7 +156,7 @@ sub _add_app_to_ua
 sub _add_app
 {
   my($self, $url, $app, $index) = @_;
-  $self->_add_app_to_ua($_, $url, $app, $index) for @{ $self->{extra_ua} };
+  $self->_add_app_to_ua($_, $url, $app, $index) for @{ $self->_extra_ua };
   return;
 }
 
@@ -158,9 +174,11 @@ sub _add_ua
   for(my $i=0; $i<=$max; $i++)
   {
     next unless defined $self->{apps}->[$i];
+    my $stopped = $self->{stopped}->[$i];
+    next if $stopped;
     $self->_add_app_to_ua($ua, $self->{urls}->[$i], $self->{apps}->[$i], $i);
   }
-  push @{ $self->{extra_ua} }, $ua;
+  push @{ $self->_extra_ua }, $ua;
   return $ua;
 }
 
@@ -184,42 +202,74 @@ sub _load_lite_app
   }, $index++);
 }
 
+sub _generate_port
+{
+  require IO::Socket::INET;
+  IO::Socket::INET->new(
+    Listen => 5, 
+    LocalAddr => '127.0.0.1',
+  )->sockport;
+}
+
+sub _create_config_helper
+{
+  my($self) = @_;
+
+  my $helper = sub { return $self };
+        
+  my $class;
+          
+  unless(defined $class)
+  {
+    if(eval q{ require Clustericious::Config::Helpers; 1})
+    {
+      $class = 'Clustericious::Config::Helpers';
+      push @Clustericious::Config::Helpers::EXPORT, 'cluster';
+    }
+    elsif(eval q{ Clustericious::Config::Plugin; 1 })
+    {
+      $class = 'Clustericious::Config::Plugin';
+      push @Clustericious::Config::Plugin::EXPORT, 'cluster';
+    }
+  }
+  
+  return unless $class;
+        
+  do {
+    # there are a multitude of sins here aren't there?
+    no warnings 'redefine';
+    no warnings 'once';
+    no strict 'refs';
+    *{join '::', $class, 'cluster'} = $helper;
+  };
+}
+
 sub create_cluster_ok
 {
   my $self = shift;
+
+  $self->_create_config_helper;
+  my $ctx = context();
   
   my $total = scalar @_;
   my @urls = map { 
     my $url = Mojo::URL->new("http://127.0.0.1");
-    $url->port($self->t->ua->ioloop->generate_port);
+    $url->port(_generate_port);
     $url } (0..$total);
 
   push @{ $self->{urls} }, @urls;
   
   my @errors;
   
-  my $has_clustericious_config = 0;
-  
-  my $loader = Mojo::Loader->new;
   my $caller = caller;
-  $loader->load($caller);
+  Mojo::Loader::load_class($caller) if $caller ne 'main';
+
+  local @INC = @INC;
+  $self->extract_data_section(qr{^lib/}, $caller);
+  my $home = File::HomeDir->my_home;
+  unshift @INC, "$home/lib"
+    if -d "$home/lib";
 
-  local $inc_hook = sub {
-    my($self, $file) = @_;
-    my $data = $loader->data($caller, "lib/$file");
-    return unless defined $data;
-    open my $fh, '<', \$data;
-    
-    # fake out %INC because Mojo::Home freeks the heck
-    # out when it sees a CODEREF on some platforms
-    # in %INC
-    my $home = File::HomeDir->my_home;
-    mkdir "$home/mojohome" unless -d "$home/mojohome";
-    $INC{$file} = "$home/mojohome/$file";
-    
-    return $fh;
-  };
-  
   foreach my $i (0..$#_)
   {
     $self->{index}++;
@@ -229,9 +279,15 @@ sub create_cluster_ok
     my $cb;
     my $config = {};
     my $item = $_[$i];
-    if(ref($item) eq '' && $loader->data($caller, "etc/$item.conf"))
+    unless(ref $item)
     {
-      $item = [ $item, $loader->data($caller, "etc/$item.conf") ];
+      my $fn = $item;
+      $fn =~ s{::}{-}g;
+      $fn = "etc/$fn.conf";
+      if(Mojo::Loader::data_section($caller, $fn))
+      {
+        $item = [ $item, Mojo::Loader::data_section($caller, $fn) ];
+      }
     }
 
     if(ref $item eq 'ARRAY')
@@ -241,47 +297,22 @@ sub create_cluster_ok
       {
         my $home = File::HomeDir->my_home;
         mkdir "$home/etc" unless -d "$home/etc";
-        open my $fh, '>', "$home/etc/$app_name.conf";
+        open my $fh, '>', do {
+          my $fn = $app_name;
+          $fn =~ s{::}{-}g;
+          $fn = "$home/etc/$fn.conf";
+        };
         print $fh $config;
         close $fh;
         $config = {};
-        
-        unless($has_clustericious_config)
-        {
-          $has_clustericious_config = 1;
-          my $helper = sub { return $self };
-        
-          state $class;
-          
-          unless(defined $class)
-          {
-            if(eval q{ require Clustericious::Config::Helpers; 1})
-            {
-              $class = 'Clustericious::Config::Helpers';
-              push @Clustericious::Config::Helpers::EXPORT, 'cluster';
-            }
-            else
-            {
-              require Clustericious::Config::Plugin;
-              $class = 'Clustericious::Config::Plugin';
-              push @Clustericious::Config::Plugin::EXPORT, 'cluster';
-            }
-          }
-        
-          do {
-            # there are a multitude of sins here aren't there?
-            no warnings 'redefine';
-            no warnings 'once';
-            no strict 'refs';
-            *{join '::', $class, 'cluster'} = $helper;
-          };
-        }
       }
     }
     else
     {
       $app_name = $item;
     }
+    my $psgi_name = $app_name =~ /\.psgi$/ ? $app_name : "$app_name.psgi";
+
     
     my $app;
     # we want to try to load class first, so that YourApp.pm
@@ -304,12 +335,12 @@ sub create_cluster_ok
         }
         $app_name->new(\$config);
       };
-      my $first_try_error = $@;
+      $first_try_error = $@;
     }
 
     unless(defined $app)
     {
-      if(my $script = $loader->data($caller, "script/$app_name"))
+      if(my $script = Mojo::Loader::data_section($caller, "script/$app_name"))
       {
         my $home = File::HomeDir->my_home;
         mkdir "$home/script" unless -d "$home/script";
@@ -317,20 +348,39 @@ sub create_cluster_ok
         if(my $error = $@)
         { push @errors, [ $app_name, $error ] }
       }
+      
+      if(my $script = Mojo::Loader::data_section($caller, "script/$psgi_name"))
+      {
+        my $home = File::HomeDir->my_home;
+        require Mojolicious;
+        require Mojolicious::Plugin::MountPSGI;
+        $app = Mojolicious->new;
+        # TODO: check syntax of .psgi file?
+        $self->extract_data_section("script/$psgi_name", $caller);
+        $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$home/script/$psgi_name" });
+      }
     }
     
     unless(defined $app)
     {
       foreach my $dir (@{ $self->{lite_path} })
       {
-        if(($^O eq 'MSWin32' && -e "$dir/$app_name")
-        || (-x "$dir/$app_name"))
+        if($app_name !~ /\.psgi$/
+        && (($^O eq 'MSWin32' && -e "$dir/$app_name") || (-x "$dir/$app_name")))
         {
           $app = _load_lite_app("$dir/$app_name");
           if(my $error = $@)
           { push @errors, [ $app_name, $error ] }
           last;
         }
+        
+        if(-e "$dir/$psgi_name")
+        {
+          require Mojolicious;
+          require Mojolicious::Plugin::MountPSGI;
+          $app = Mojolicious->new;
+          $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$dir/$psgi_name" });
+        }
       }
     }
     
@@ -346,20 +396,58 @@ sub create_cluster_ok
     
     if(eval { $app->isa('Clustericious::App') })
     {
-      $app->helper(auth_ua => sub { 
-        die "no plug auth service configured for test cluster, either turn off authentication or use Test::Clustericious::Cluster#create_plugauth_lite_ok"
-          unless defined $self->{auth_ua};
-        $self->{auth_ua};
-      });
+      if($app->can('auth_ua'))
+      {
+        $app->helper(auth_ua => sub { 
+          die "no plug auth service configured for test cluster, either turn off authentication or use Test::Clustericious::Cluster#create_plugauth_lite_ok"
+            unless defined $self->{auth_ua};
+          $self->{auth_ua};
+        });
+      }
+    }
+
+    if($app && $app->isa('Clustericious::App'))
+    {
+      my $fn = $app_name;
+      $fn =~ s{::}{-}g;
+      $fn = "$home/etc/$fn.conf";
+      unless(-e $fn)
+      {
+        # YAML::XS is a prereq for Clustericious
+        # so we can use it here.
+        require YAML::XS;
+        my %config = %{ $app->config };
+        $config{url} //= $self->url->to_string;
+        my $payload = YAML::XS::Dump(\%config);
+        open my $fh, '>', $fn;
+        print $fh $payload;
+        close $fh;
+      }
     }
 
     $cb->() if defined $cb;
   }
 
-  my $tb = __PACKAGE__->builder;
-  $tb->ok(@errors == 0, "created cluster");
-  $tb->diag("exception: " . $_->[0] . ': ' . $_->[1]) for @errors;
+  $ctx->ok(@errors == 0, "created cluster");
+  $ctx->diag("exception: " . $_->[0] . ': ' . $_->[1]) for @errors;
   
+  if($INC{'Clustericious/App.pm'})
+  {
+    eval { require Clustericious::Client };
+    if(!$@ && Clustericious::Client->can('_mojo_user_agent_factory'))
+    {
+      Clustericious::Client->_mojo_user_agent_factory(sub {
+        $self->create_ua;
+      });
+    }
+  }
+  
+  if(defined $self->{t})
+  {
+    $self->_update_default_server;
+  }
+  
+  $ctx->release;
   return $self;
 }
 
@@ -368,23 +456,25 @@ sub create_plugauth_lite_ok
 {
   my($self, %args) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
   if(eval q{ use Clustericious; 1 } && ! eval q{ use Clustericious 0.9925; 1 })
   {
     croak "creat_plugin_lite_ok requires Clustericious 0.9925 or better (see Test::Clustericious::Test for details)";
   }
-  
+
+  my @diag;
+
   if($self->{auth_ua} || $self->{auth_url})
   {
     $ok = 0;
-    $tb->diag("only use create_plugauth_lite_ok once");
+    push @diag, 'only use create_plugauth_lite_ok once';
   }
   else
   {
     my $ua = $self->{auth_ua} = $self->_add_ua;
     my $url = Mojo::URL->new("http://127.0.0.1");
-    $url->port($self->t->ua->ioloop->generate_port);
+    $url->port(_generate_port);
   
     eval {
       require PlugAuth::Lite;
@@ -395,12 +485,14 @@ sub create_plugauth_lite_ok
     };
     if(my $error = $@)
     {
-      $tb->diag("error: $error");
+      $ctx->diag("error: $error");
       $ok = 0;
     }
   }
   
-  $tb->ok($ok, "PlugAuth::Lite instance on " . $self->{auth_url});
+  $ctx->ok($ok, "PlugAuth::Lite instance on " . $self->{auth_url});
+  $ctx->diag($_) for @diag;
+  $ctx->release;
   
   return $self;
 }
@@ -410,7 +502,7 @@ sub stop_ok
 {
   my($self, $index, $test_name) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
   my $error;
   
@@ -423,18 +515,27 @@ sub stop_ok
     eval { @{ $self->{app_servers}->[$index] } = () };
     $error = $@;
     $ok = 0 if $error;
+    
+    if($index == $#{ $self->apps } && $self->{t})
+    {
+      $self->t->ua->server(Mojo::UserAgent::Server->new);
+    }
+    
   }
   else
   {
-    $tb->diag("no such app for index: $index");
+    $error = "no such app for index: $index";
     $ok = 0;
   }
   
+  $self->{stopped}->[$index] = 1 if $ok;
+  
   $test_name //= "stop service ($index)";
   
-  my $ret = $tb->ok($ok, $test_name);
+  my $ret = $ctx->ok($ok, $test_name);
   
-  $tb->diag($error) if $error;
+  $ctx->diag($error) if $error;
+  $ctx->release;
   
   $ret;
 }
@@ -444,8 +545,10 @@ sub start_ok
 {
   my($self, $index, $test_name) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
+  my $error;
+
   my $app = $self->apps->[$index];
   if(defined $app)
   {
@@ -456,19 +559,62 @@ sub start_ok
     };
     if(my $error = $@)
     {
-      $tb->diag("error in start: $error");
+      $ctx->diag("error in start: $error");
       $ok = 0;
     }
+
   }
   else
   {
-    $tb->diag("no such app for index: $index");
+    $error = "no such app for index: $index";
     $ok = 0;
   }
   
+  $self->{stopped}->[$index] = 0 if $ok;
+
+  if($index == $#{ $self->apps } && $self->{t})
+  {
+    $self->_update_default_server;
+  }
+
   $test_name //= "start service ($index)";
   
-  $tb->ok($ok, $test_name);
+  $ctx->ok($ok, $test_name);
+  $ctx->diag($error) if $error;
+  $ctx->release;
+  
+  $ok;
+}
+
+
+sub is_stopped
+{
+  my($self, $index, $test_name) = @_;
+  
+  my $ok = !!$self->{stopped}->[$index];
+  
+  $test_name //= "servers ($index) is stopped";
+  
+  my $ctx = context();
+  $ctx->ok($ok, $test_name);
+  $ctx->release;
+  $ok;
+}
+
+
+sub isnt_stopped
+{
+  my($self, $index, $test_name) = @_;
+  
+  my $ok = !$self->{stopped}->[$index];
+  
+  $test_name //= "servers ($index) is not stopped";
+  
+  my $ctx = context();
+  $ctx->ok($ok, $test_name);
+  $ctx->release;
+  
+  $ok;
 }
 
 
@@ -477,6 +623,66 @@ sub create_ua
   shift->_add_ua;
 }
 
+
+sub extract_data_section
+{
+  my($class, $regex, $caller) = @_;
+
+  $regex //= qr{};
+  
+  unless(ref $regex eq 'Regexp')
+  {
+    $regex = quotemeta $regex;
+    $regex = qr{^$regex$};
+  }
+  
+  $caller //= caller;
+  my $all = Mojo::Loader::data_section $caller;
+  my $home = File::HomeDir->my_home;
+  my $ctx = context();
+
+  foreach my $name (keys %$all)
+  {
+    use autodie;
+    next unless $name =~ $regex;
+    my $basename = File::Basename::basename $name;
+    my $dir      = File::Basename::dirname  $name;
+
+    unless(-d "$home/$dir")
+    {
+      $ctx->note("[extract] DIR  $home/$dir");
+      File::Path::mkpath "$home/$dir", 0, 0700;
+    }
+    unless(-f "$home/$dir/$basename")
+    {
+      $ctx->note("[extract] FILE $home/$dir/$basename");
+      open my $fh, '>', "$home/$dir/$basename";
+      print $fh $all->{$name};
+      close $fh;
+    }
+  }
+  
+  $ctx->release;
+  $class;
+}
+
+
+sub client
+{
+  my($self, $n) = @_;
+  my $app = $self->apps->[$n];
+  return unless eval { $app->isa('Clustericious::App') };
+  my $client_class = ref($app) . '::Client';
+  unless($client_class->can('new') || eval qq{ require $client_class; $client_class->isa('Clustericious::Client') })
+  {
+    require Clustericious::Client;
+    $client_class = 'Clustericious::Client';
+  }
+  my %config = %{ $app->config };
+  $config{url} = $self->urls->[$n];
+  my $client = $client_class->new( config => Clustericious::Config->new(\%config) );
+}
+
 1;
 
 __END__
@@ -491,10 +697,11 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.14_01
+version 0.36_01
 
 =head1 SYNOPSIS
 
+ use Test2::Bundle::More;
  use Test::Clustericious::Cluster;
  
  # suppose MyApp1 isa Clustericious::App and
@@ -508,12 +715,14 @@ version 0.14_01
  $t->get_ok("$url[0]/arbitrary_path");  # tests against MyApp1
  $t->get_ok("$url[1]/another_path");    # tests against MyApp2
  
+ done_testing;
+ 
  __DATA__
  
  @@ etc/MyApp1.conf
  ---
  # Clustericious configuration 
- url <%= cluster->url %>
+ url: <%= cluster->url %>
  url_for_my_app2: <%= cluster->urls->[1] %>
 
 =head1 DESCRIPTION
@@ -603,11 +812,15 @@ example that mocks parts of L<Net::hostent>:
  use strict;
  use warnings;
  use Test::Clustericious::Cluster;
- use Test::More tests => 2;
+ use Test2::Bundle::More;
+ 
+ eval q{ use Net::hostent };
+ is $@, '';
  
- use_ok('Net::hostent');
  is gethost('bar')->name, 'foo.example.com', 'gethost(bar).name = foo.example.com';
  
+ done_testing;
+ 
  __DATA__
  
  @@ lib/Net/hostent.pm
@@ -646,7 +859,7 @@ If not provided, then a new one will be created.
 =head3 lite_path
 
 List reference of paths to search for L<Mojolicious::Lite>
-apps.
+or PSGI apps.
 
 =head1 ATTRIBUTES
 
@@ -713,6 +926,12 @@ lite application.  The script for the lite app must be executable.
 You can specify additional directories to search using the
 C<lite_path> argument to the constructor.
 
+This can also be a PSGI application.  In this case it needs to be
+in the C<__DATA__> section of your test and it must have a name
+in the form C<script/app.psgi>.  This also requires
+L<Mojolicious::Plugin::MountPSGI> already be installed so if you
+use this feature make sure you declare that as a prereq.
+
 =item list reference in the form: [ string, hashref ]
 
 The string is taken to be the L<Mojolicious> application name.
@@ -752,12 +971,12 @@ For example:
  use strict;
  use warnings;
  use Test::Clustericious::Cluster;
- use Test::More;
+ use Test2::Bundle::More;
  BEGIN {
-   plan skip_all => 'test requires Clustericious 0.9925'
-     unless eval q{ use Clustericious 0.9925; 1 };
-   plan skip_all => 'test requires PlugAuth::Lite'
-     unless eval q{ use PlugAuth::Lite; 1 };
+   skip_all 'test requires Clustericious 0.9925'
+     unless eval q{ use Clustericious 1.00; 1 };
+   skip_all 'test requires PlugAuth::Lite'
+     unless eval q{ use PlugAuth::Lite 0.30; 1 };
  };
 
 =head2 stop_ok
@@ -781,6 +1000,20 @@ Start the given service.  The service is specified by
 an index, the first application when you created the
 cluster is 0, the second is 1, and so on.
 
+=head2 is_stopped
+
+ $cluster->is_stopped( $index );
+ $cluster->is_stopped( $index, $test_name );
+
+Passes if the given service is stopped.
+
+=head2 isnt_stopped
+
+ $cluster->isnt_stopped( $index );
+ $cluster->isnt_stopped( $index, $test_name );
+
+Passes if the given service is not stopped.
+
 =head2 create_ua
 
  my $ua = $cluster->create_ua;
@@ -788,6 +1021,26 @@ cluster is 0, the second is 1, and so on.
 Create a new instance of Mojo::UserAgent which can be used
 to connect to nodes in the test cluster.
 
+=head2 extract_data_section
+
+ $cluster->extract_data_section($regex);
+ Test::Clustericious::Cluster->extract_data_section($regex);
+
+Extract the files from the data section of the current package
+that match the given regex.  C<$regex> can also be a plain
+string for an exact filename match.
+
+=head2 client
+
+ my $client = $cluster->client($n);
+
+Return a L<Clustericious::Client> object for use with the C<$n>th
+service in the cluster.  If there is a corresponding C<YourService::Client>
+class then it will be used.  Otherwise you will get a generic
+L<Clustericious::Client> object with the correct URL configured.
+
+This method only works with L<Clustericious> services.
+
 =head1 CAVEATS
 
 Some combination of Mojolicious, FreeBSD, IPv6 and TLS/SSL
@@ -807,8 +1060,6 @@ https://github.com/plicease/Test-Clustericious-Cluster/issues/3
 
 If you want to help.
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
